<?php
namespace BackOfficeOptimizer\Libraries;

use Doctrine\DBAL\DriverManager;
use Zeedhi\Framework\Session\Session;
use BackOfficeOptimizer\Libraries\JWT;

class ConnectionFactory extends \Zeedhi\Framework\ORM\ConnectionFactory {
    public static function updateConnectionParams(array $connectionParams, $config = null, $eventManager = null){
        $nrOrg = false;
		$token = isset($_COOKIE["optimizer"]) ? $_COOKIE["optimizer"] : "";
		$session = empty($token) ? array() : JWT::getTokenData($token);

        if(isset($session) && count($session) > 0) {
            $nrOrg = isset($session['NRORG']) ? $session['NRORG'] : false;

            //Set current DBNAME in session for use in login session
            if(isset($connectionParams['sessionMode'])) {
                $session['CURRENT_DBNAME'] = preg_replace('/[^A-Za-z0-9\-]/', '', self::encrypt($connectionParams['dbname']));
            } else {
                $session['CURRENT_DBNAME'] = preg_replace('/[^A-Za-z0-9\-]/', '', self::encrypt($connectionParams['user']));
            }
        }

        if ($nrOrg && isset($connectionParams['useVpd']) && $connectionParams['useVpd'] == 'true') {
            if (isset($connectionParams['vpdWithWallet']) && $connectionParams['vpdWithWallet'] == 'true') {
                unset($connectionParams['host']);
                unset($connectionParams['port']);
                $connectionParams['user'] = '/';
                $connectionParams['password'] = '';
                $connectionParams['dbname'] = 'USR_ORG_' . $nrOrg;
                $connectionParams['sessionMode'] = -2147483648;
            } else {
                $connectionParams['user'] = 'USR_ORG_' . $nrOrg;
                $connectionParams['password'] = $connectionParams['vpdPassword'];
                if (isset($connectionParams['isWallet']) && $connectionParams['isWallet'] == 'true') {
                    $connectionParams['dbname'] = isset($connectionParams['vpdDBNAME'])
                        ? $connectionParams['vpdDBNAME']
                        : $connectionParams['vpdDBName'];
                    $connectionParams['dbname'] = $connectionParams['vpdDBNAME'];
                    $connectionParams['host'] = $connectionParams['vpdHost'];
                    $connectionParams['port'] = $connectionParams['vpdPort'];
                    $connectionParams['service'] = $connectionParams['vpdService'];
                    unset($connectionParams['sessionMode']);
                }
            }
        }
        if(empty($connectionParams["password"])) {
            $connectionParams["password"] = '';
        } else if(isset($connectionParams["isEncrypted"]) && $connectionParams["isEncrypted"] == 'true') {
            $connectionParams["password"] = self::decrypt($connectionParams["password"]);
        }

        return DriverManager::getConnection($connectionParams, $config, $eventManager);
     }
}